@@ -6,9 +6,9 @@ if 0;
 
 # ============================================================================
 
-# $Id: snmpset.pl,v 2.1 2002/05/06 12:30:37 dtown Exp $
+# $Id: snmpset.pl,v 2.2 2003/05/06 11:00:46 dtown Exp $
 
-# Copyright (c) 2000-2002 David M. Town <dtown@cpan.org>
+# Copyright (c) 2000-2003 David M. Town <dtown@cpan.org>
 # All rights reserved.
 
 # This program is free software; you may redistribute it and/or modify it
@@ -16,17 +16,17 @@ if 0;
 
 # ============================================================================
 
-use Net::SNMP qw(:asn1 oid_lex_sort DEBUG_ALL);
+use Net::SNMP 4.1.0 qw(:asn1 DEBUG_ALL);
 use Getopt::Std;
 
 use strict;
 use vars qw($SCRIPT $VERSION %OPTS);
 
 $SCRIPT  = 'snmpset';
-$VERSION = '2.0.1';
+$VERSION = '2.1.0';
 
 # Validate the command line options
-if (!getopts('a:A:c:dE:m:n:p:r:t:u:v:X:', \%OPTS)) {
+if (!getopts('a:A:c:dE:m:n:p:r:t:u:v:x:X:', \%OPTS)) {
    _usage();
 }
 
@@ -48,6 +48,7 @@ my ($s, $e) = Net::SNMP->session(
    exists($OPTS{t}) ? (-timeout      =>  $OPTS{t}) : (),
    exists($OPTS{u}) ? (-username     =>  $OPTS{u}) : (),
    exists($OPTS{v}) ? (-version      =>  $OPTS{v}) : (),
+   exists($OPTS{x}) ? (-privprotocol =>  $OPTS{x}) : (),
    exists($OPTS{X}) ? (-privpassword =>  $OPTS{X}) : ()
 );
 
@@ -73,7 +74,7 @@ if (!defined($s->set_request(@args))) {
 }
 
 # Print the results
-foreach (oid_lex_sort(keys(%{$s->var_bind_list()}))) {
+foreach ($s->var_bind_names()) {
    printf("%s => %s\n", $_, $s->var_bind_list()->{$_});
 }
 
@@ -133,40 +134,33 @@ sub _exit
 
 sub _usage
 {
-   printf("%s v%s\n", $SCRIPT, $VERSION);
-
-   printf(
-      "Usage: %s [options] <hostname> <oid> <type> <value> [...]\n",
-      $SCRIPT
-   );
-
-   printf("Options: -v 1|2c|3      SNMP version\n");
-   printf("         -d             Enable debugging\n");
-
-   printf("   SNMPv1/SNMPv2c:\n");
-   printf("         -c <community> Community name\n");
-
-   printf("   SNMPv3:\n");
-   printf("         -u <username>  Username (required)\n");
-   printf("         -E <engineid>  Context Engine ID\n");
-   printf("         -n <name>      Context Name\n");
-   printf("         -a md5|sha1    Authentication protocol\n");
-   printf("         -A <password>  Authentication password\n");
-   printf("         -X <password>  Privacy password\n");
-
-   printf("   Transport Layer:\n");
-   printf("         -m <octets>    Maximum message size\n");
-   printf("         -p <port>      Destination UDP port\n");
-   printf("         -r <attempts>  Number of retries\n");
-   printf("         -t <secs>      Timeout period\n");
-
-   printf("Valid type values:\n");
-   printf("          a - IpAddress         o - OBJECT IDENTIFIER\n");
-   printf("          c - Counter           p - Opaque\n");
-   printf("          C - Counter64         s - OCTET STRING\n");
-   printf("          g - Gauge             t - TimeTicks\n");
-   printf("          i - INTEGER           h - OCTET STRING (hex)\n");
-
+   print << "USAGE";
+$SCRIPT v$VERSION
+Usage: $SCRIPT [options] <hostname> <oid> <type> <value> [...]
+Options: -v 1|2c|3      SNMP version
+         -d             Enable debugging
+   SNMPv1/SNMPv2c:
+         -c <community> Community name
+   SNMPv3:
+         -u <username>  Username (required)
+         -E <engineid>  Context Engine ID
+         -n <name>      Context Name
+         -a <authproto> Authentication protocol <md5|sha>
+         -A <password>  Authentication password
+         -x <privproto> Privacy protocol <des|3des|aes128|aes192|aes256>
+         -X <password>  Privacy password
+   Transport Layer:
+         -m <octets>    Maximum message size
+         -p <port>      Destination UDP port
+         -r <attempts>  Number of retries
+         -t <secs>      Timeout period
+Valid type values:
+          a - IpAddress         o - OBJECT IDENTIFIER
+          c - Counter           p - Opaque
+          C - Counter64         s - OCTET STRING
+          g - Gauge             t - TimeTicks
+          i - INTEGER           h - OCTET STRING (hex)
+USAGE
    exit 1;
 }
 
